# Enable RTL formatting for the current R Markdown document
markdown_rtl()
# After enabling RTL formatting, proceed to knit the R Markdown document as usual.
# The output and messages will be formatted for RTL languages.
Run the code above in your browser using DataLab