Learn R Programming

RTLknitr (version 1.0.0)

markdown_rtl_header: Generate a YAML header for an R Markdown document with RTL support

Description

This function generates a YAML header for an R Markdown document that will produce a PDF output with support for Persian typesetting using the xepersian package and the Arial font.

Usage

markdown_rtl_header()

Arguments

Value

A character string containing the YAML header.