markdown_rtl_header: Generate a YAML header for an R Markdown document with RTL support
Description
This function generates a YAML header for an R Markdown document that will produce a PDF output
with support for Persian typesetting using the xepersian package and the Arial font.